@@ -3,6 +3,11 @@
 
 read_dcf <- function(file) {
   lines <- readLines(file)
+  no_tws_fields <- sub(
+    ":$",
+    "",
+    grep("^[^\\s]+:$", lines, perl = TRUE, value = TRUE)
+  )
 
   con <- textConnection(lines, local = TRUE)
   fields <- colnames(read.dcf(con))
@@ -12,5 +17,10 @@ read_dcf <- function(file) {
   res <- read.dcf(con, keep.white = fields)
   close(con)
 
-  create_fields(fields, res[1, ])
+  notws <- res[1, match(no_tws_fields, fields)]
+
+  list(
+    dcf = create_fields(fields, res[1, ]),
+    notws = notws
+  )
 }
